@@ -4,7 +4,8 @@ from .packer import Packer, JsonPacker, YmlPacker, PicklePacker, \
 from .multi_task import MultiTaskLauncher, \
     multi_task_launcher, multi_thread_launcher, \
     multi_process_launcher, thread_pool_executor, \
-    wait_a_task, wait_tasks, multi_task_launcher_batch
+    wait_a_task, wait_tasks, \
+    multi_task_launcher_batch, multi_call
 from .entity import SaveableEntity, IterableEntity
 from .registry import AtexitRegistry, ThreadRegistry
 from .mapper import Mapper, MapperFactory
